# Smith

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/37211993f9784a51a3ec2f49be2447ff)](https://www.codacy.com/app/VictorAlessander/SmithX?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=VictorAlessander/SmithX&amp;utm_campaign=Badge_Grade)

# Project Description

Webscraper to get some informations of products in e-commerce, avoiding the user to enter in the website many times only to see if any product have special offer.

# Backlog

- API Gateway to get the requests and pass them to Smith (Asynchronous)
- Database connection
- Frontend to make easier handle with the data scraped (metrics, charts, comparisons)
- Improvement in program.py to avoid multiples "if" statements